Examples
========

Three examples are provided to demonstrate the basic functionality
of the MAX BLE HCI library. The source code for these examples can
be found in the :file:`examples` directory.

Example 1: Hello HCI
--------------------

.. literalinclude:: /examples/hello_hci.py
    :language: python

Example 2: Direct-Test Mode
---------------------------

.. literalinclude:: /examples/dtm.py
    :language: python

Example 3: Connection Mode
--------------------------

.. literalinclude:: /examples/connection.py
    :language: python
